"use strict";Object.defineProperty(exports, "__esModule", {value: true});// src/utils/runners.ts
var runNode = async (handler, handlerOptions, serverOptions) => {
  const [
    { createServer },
    { getNodeAdapter }
  ] = await Promise.all([
    Promise.resolve().then(() => require("http")),
    Promise.resolve().then(() => require("../adapters/node/index.cjs"))
  ]);
  const nodeHandler = getNodeAdapter(handler);
  const server = createServer(await nodeHandler(...handlerOptions));
  await new Promise((resolve) => server.listen(serverOptions == null ? void 0 : serverOptions.port, resolve));
};
var runExpress = async (handler, handlerOptions, serverOptions) => {
  const [
    { default: express },
    { getExpressAdapter }
  ] = await Promise.all([
    Promise.resolve().then(() => require("express")),
    Promise.resolve().then(() => require("../adapters/express/index.cjs"))
  ]);
  const expressHandler = getExpressAdapter(handler);
  const app = express();
  app.use(await expressHandler(...handlerOptions));
  await new Promise((resolve) => app.listen(serverOptions == null ? void 0 : serverOptions.port, resolve));
};
var runFastify = async (handler, handlerOptions, serverOptions) => {
  const [
    { default: fastify },
    { getFastifyAdapter }
  ] = await Promise.all([
    Promise.resolve().then(() => require("fastify")),
    Promise.resolve().then(() => require("../adapters/fastify/index.cjs"))
  ]);
  const getFastifyPlugin = getFastifyAdapter(handler);
  const server = fastify();
  server.register(await getFastifyPlugin(...handlerOptions));
  await server.listen({ port: serverOptions == null ? void 0 : serverOptions.port });
};
var runH3 = async (handler, handlerOptions, serverOptions) => {
  const [
    { createServer },
    { createApp },
    { getH3Adapter }
  ] = await Promise.all([
    Promise.resolve().then(() => require("http")),
    Promise.resolve().then(() => require("h3")),
    Promise.resolve().then(() => require("../adapters/h3/index.cjs"))
  ]);
  const h3Handler = getH3Adapter(handler);
  const app = createApp();
  app.use(await h3Handler(...handlerOptions));
  const server = createServer(app);
  await new Promise((resolve) => server.listen(serverOptions == null ? void 0 : serverOptions.port, resolve));
};
var runKoa = async (handler, handlerOptions, serverOptions) => {
  const [
    { default: Koa },
    { getKoaAdapter }
  ] = await Promise.all([
    Promise.resolve().then(() => require("koa")),
    Promise.resolve().then(() => require("../adapters/koa/index.cjs"))
  ]);
  const koaHandler = getKoaAdapter(handler);
  const app = new Koa();
  app.use(await koaHandler(...handlerOptions));
  await new Promise((resolve) => app.listen(serverOptions == null ? void 0 : serverOptions.port, resolve));
};






exports.runExpress = runExpress; exports.runFastify = runFastify; exports.runH3 = runH3; exports.runKoa = runKoa; exports.runNode = runNode;
